@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:critical reason:data-parser
 
 #include <QGuiApplication>
 #include <QBuffer>
@@ -11,6 +12,12 @@
 
 QT_BEGIN_NAMESPACE
 
+// QImage <-> CGImage conversion functions from QtGui on darwin
+CGImageRef qt_mac_toCGImage(const QImage &qImage);
+QImage qt_mac_toQImage(CGImageRef image);
+
+namespace NS_IIOF_HELPERS {
+
 // Callbacks for sequential data provider & consumer:
 
 static size_t cbGetBytes(void *info, void *buffer, size_t count)
@@ -55,10 +62,6 @@ static size_t cbPutBytes(void *info, const void *buffer, size_t count)
 }
 
 
-// QImage <-> CGImage conversion functions from QtGui on darwin
-CGImageRef qt_mac_toCGImage(const QImage &qImage);
-QImage qt_mac_toQImage(CGImageRef image);
-
 QImageIOPlugin::Capabilities QIIOFHelpers::systemCapabilities(const QString &uti)
 {
     QImageIOPlugin::Capabilities res;
@@ -286,4 +289,6 @@ bool QIIOFHelper::writeImage(const QImage &in, const QString &uti)
     return CGImageDestinationFinalize(cgImageDest);
 }
 
+}
+
 QT_END_NAMESPACE
